@@ -8,10 +8,10 @@ pyside_library_soversion = "6.10"
 version = "6.10.1"
 version_info = (6, 10, 1, "", "")
 
-__build_date__ = '2025-12-17T17:37:07+00:00'
-
-
-
+__build_date__ = '2026-01-11T05:40:07+00:00'
+__build_commit_date__ = '2025-12-15T15:54:57+00:00'
+__build_commit_hash__ = 'ff2eb3a2007bac3c2745229fcefc6cd34ae4f31f'
+__build_commit_hash_described__ = '6.10.1-2'
 
 
 
